DisturbancePercentCover: Disturbance cover by disturbance type and transect

Description Usage Arguments Details Value

View source: R/disturbance-analysis.R

Description

Disturbance cover by disturbance type and transect

Usage

1
2
DisturbancePercentCover(conn, path.to.data, park, spring, field.season,
  drop.zeroes = FALSE, data.source = "database")

Arguments

conn

Database connection generated from call to OpenDatabaseConnection(). Ignored if data.source is "local".

path.to.data

The directory containing the csv data exports generated from SaveDataToCsv(). Ignored if data.source is "database".

park

Optional. Four-letter park code to filter on, e.g. "MOJA".

spring

Optional. Spring code to filter on, e.g. "LAKE_P_BLUE0".

field.season

Optional. Field season name to filter on, e.g. "2019".

drop.zeroes

Should percent covers of 0 be included in the dataset? Defaults to FALSE.

data.source

Character string indicating whether to access data in the spring veg database ("database", default) or to use data saved locally ("local"). In order to access the most up-to-date data, it is recommended that you select "database" unless you are working offline or your code will be shared with someone who doesn't have access to the database.

Details

Only includes data from visits labeled 'Primary.' Percent cover is calculated only from points at which data were collected - if only three points were recorded for a transect and one of them had bike disturbance, the disturbance type BK would have 33.3

Value

A tibble with columns Park, SpringCode, SpringName, FieldSeason, TransectNumber, CanopyPercentCover


nationalparkservice/mojn-sv-rpackage documentation built on Oct. 29, 2021, 7:13 p.m.