Description Usage Arguments Details Value
View source: R/vegetation-figures.R
Table of species detected through LPI vs veg inventory
1 2 | TableSpeciesPerTransect(conn, path.to.data, park, spring, field.season,
dt.options, data.source = "database", ...)
|
conn |
Database connection generated from call to |
path.to.data |
The directory containing the csv data exports generated from |
park |
Optional. Four-letter park code to filter on, e.g. "MOJA". |
spring |
Optional. Spring code to generate a plot for, e.g. "LAKE_P_BLUE0". |
field.season |
Optional. Field season name to filter on, e.g. "2019". |
dt.options |
Optional. Options to be passed to DT::datatable(). |
data.source |
Character string indicating whether to access data in the spring veg database ( |
... |
Optional. Additional arguments to be passed to DT::datatable(). |
Omits TBD and UNK species from counts. Only includes data from visits labeled 'Primary.'
An HTML widget.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.