Description Usage Arguments Details Value
View source: R/disturbance-analysis.R
Disturbance cover by disturbance type and transect
1 2 | DisturbancePercentCover(conn, path.to.data, park, spring, field.season,
drop.zeroes = FALSE, data.source = "database")
|
conn |
Database connection generated from call to |
path.to.data |
The directory containing the csv data exports generated from |
park |
Optional. Four-letter park code to filter on, e.g. "MOJA". |
spring |
Optional. Spring code to filter on, e.g. "LAKE_P_BLUE0". |
field.season |
Optional. Field season name to filter on, e.g. "2019". |
drop.zeroes |
Should percent covers of 0 be included in the dataset? Defaults to FALSE. |
data.source |
Character string indicating whether to access data in the spring veg database ( |
Only includes data from visits labeled 'Primary.' Percent cover is calculated only from points at which data were collected - if only three points were recorded for a transect and one of them had bike disturbance, the disturbance type BK would have 33.3
A tibble with columns Park, SpringCode, SpringName, FieldSeason, TransectNumber, CanopyPercentCover
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.